summaryrefslogtreecommitdiff
path: root/include/comphelper/sequenceashashmap.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'include/comphelper/sequenceashashmap.hxx')
-rw-r--r--include/comphelper/sequenceashashmap.hxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/comphelper/sequenceashashmap.hxx b/include/comphelper/sequenceashashmap.hxx
index e6d44a3678be..f6c5c092b78f 100644
--- a/include/comphelper/sequenceashashmap.hxx
+++ b/include/comphelper/sequenceashashmap.hxx
@@ -81,7 +81,7 @@ class COMPHELPER_DLLPUBLIC SequenceAsHashMap : public SequenceAsHashMapBase
SequenceAsHashMap(const ::com::sun::star::uno::Sequence< ::com::sun::star::beans::NamedValue >& lSource);
//---------------------------------------
/** @short not realy used but maybe useful :-)
*/
~SequenceAsHashMap();
@@ -208,7 +208,7 @@ class COMPHELPER_DLLPUBLIC SequenceAsHashMap : public SequenceAsHashMapBase
specified default value otherwise.
@descr If a value should be extracted only in case
- the requsted property exists realy (without creating
+ the requsted property exists really (without creating
of new items as it the index operator of a
has_map does!) this method can be used.
@@ -81,7 +81,7 @@ class COMPHELPER_DLLPUBLIC SequenceAsHashMap : public SequenceAsHashMapBase
SequenceAsHashMap(const ::com::sun::star::uno::Sequence< ::com::sun::star::beans::NamedValue >& lSource);
//---------------------------------------
- /** @short not realy used but maybe useful :-)
+ /** @short not really used but maybe useful :-)
*/
~SequenceAsHashMap();